@@ -655,6 +655,8 @@ namespace Magick
   using MagickLib::IsImagesEqual;
   using MagickLib::IsSubimage;
   using MagickLib::LessValue;
+  using MagickLib::LevelImage;
+  using MagickLib::LevelImageChannel;
   using MagickLib::LocaleCompare;
   using MagickLib::LogMagickEvent;
   using MagickLib::MagickInfo;
