@@ -174,7 +174,8 @@ static Image *ReadCINImage(const ImageInfo *image_info,
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   image=AllocateImage(image_info);
@@ -387,7 +388,7 @@ static MagickBooleanType WriteCINImage(const ImageInfo *image_info,Image *image)
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
@@ -398,9 +399,9 @@ static MagickBooleanType WriteCINImage(const ImageInfo *image_info,Image *image)
   max_color.red=0;
 	max_color.green=0;
 	max_color.blue=0;
-  min_color.red=MaxRGB;
-	min_color.green=MaxRGB;
-	min_color.blue=MaxRGB;
+  min_color.red=QuantumRange;
+	min_color.green=QuantumRange;
+	min_color.blue=QuantumRange;
   for (y=0; y < (long) image->rows; y++)
   {
     p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
@@ -565,9 +566,9 @@ static MagickBooleanType WriteCINImage(const ImageInfo *image_info,Image *image)
     for (x=0; x < (long) image->columns; x++)
     {
       pixel=(unsigned long)
-        (((long) ((1023L*p->red+MaxRGB/2)/MaxRGB) & 0x3ff) << 22) |
-        (((long) ((1023L*p->green+MaxRGB/2)/MaxRGB) &0x3ff) << 12) |
-        (((long) ((1023L*p->blue+MaxRGB/2)/MaxRGB) &0x3ff) << 2);
+        (((long) ((1023L*p->red+QuantumRange/2)/QuantumRange) & 0x3ff) << 22) |
+        (((long) ((1023L*p->green+QuantumRange/2)/QuantumRange) &0x3ff) << 12) |
+        (((long) ((1023L*p->blue+QuantumRange/2)/QuantumRange) &0x3ff) << 2);
       (void) WriteBlobMSBLong(image,pixel);
       p++;
     }
