@@ -167,7 +167,8 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   image=AllocateImage(image_info);
@@ -187,8 +188,8 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
   headersize=ReadBlobMSBLong(image);
   for (i=0; i < 764; i++)
     (void) ReadBlobByte(image);
-  image->columns= ReadBlobMSBLong(image);
-  image->rows= ReadBlobMSBLong(image);
+  image->columns=ReadBlobMSBLong(image);
+  image->rows=ReadBlobMSBLong(image);
   for (i=0; i < 20; i++)
     (void) ReadBlobByte(image);
   colortype=ReadBlobByte(image);
@@ -387,7 +388,7 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
@@ -431,9 +432,9 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
       break;
     for (x=0; x < (long) image->columns; x++)
     {
-      pixel=(((long) ((1023L*p->red+MaxRGB/2)/MaxRGB) & 0x3ff) << 22) |
-        (((long) ((1023L*p->green+MaxRGB/2)/MaxRGB) &0x3ff) << 12) |
-        (((long) ((1023L*p->blue+MaxRGB/2)/MaxRGB) &0x3ff) << 2);
+      pixel=(((long) ((1023L*p->red+QuantumRange/2)/QuantumRange) & 0x3ff) << 22) |
+        (((long) ((1023L*p->green+QuantumRange/2)/QuantumRange) &0x3ff) << 12) |
+        (((long) ((1023L*p->blue+QuantumRange/2)/QuantumRange) &0x3ff) << 2);
       (void) WriteBlobMSBLong(image,pixel);
       p++;
     }
