@@ -155,7 +155,7 @@ static MagickBooleanType DecodeImage(Image *image,const Quantum opacity)
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   packet=(unsigned char *) AcquireMagickMemory(256);
   prefix=(short *) AcquireMagickMemory(MaxStackSize*sizeof(*prefix));
   suffix=(unsigned char *) AcquireMagickMemory(MaxStackSize);
@@ -845,7 +845,8 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   image=AllocateImage(image_info);
@@ -961,7 +962,7 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
           Allocate next image structure.
         */
         AllocateNextImage(image_info,image);
-        if (image->next == (Image *) NULL)
+        if (GetNextImageInList(image) == (Image *) NULL)
           {
             image=DestroyImageList(image);
             global_colormap=(unsigned char *)
@@ -1238,7 +1239,7 @@ static MagickBooleanType WriteGIFImage(const ImageInfo *image_info,Image *image)
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
@@ -1257,7 +1258,7 @@ static MagickBooleanType WriteGIFImage(const ImageInfo *image_info,Image *image)
       page.width=next_image->columns+page.x;
     if ((next_image->rows+page.y) > page.height)
       page.height=next_image->rows+page.y;
-    next_image=next_image->next;
+    next_image=GetNextImageInList(next_image);
   }
   /*
     Allocate colormap.
@@ -1290,7 +1291,7 @@ static MagickBooleanType WriteGIFImage(const ImageInfo *image_info,Image *image)
     Write images to file.
   */
   interlace=write_info->interlace;
-  if ((write_info->adjoin != MagickFalse) && (image->next != (Image *) NULL))
+  if ((write_info->adjoin != MagickFalse) && (GetNextImageInList(image) != (Image *) NULL))
     interlace=NoInterlace;
   scene=0;
   do
@@ -1342,7 +1343,7 @@ static MagickBooleanType WriteGIFImage(const ImageInfo *image_info,Image *image)
               indexes=GetIndexes(image);
               for (x=0; x < (long) image->columns; x++)
               {
-                if ((double) p->opacity >= (MaxRGB-image->fuzz))
+                if ((double) p->opacity >= (QuantumRange-image->fuzz))
                   indexes[x]=(IndexPacket) opacity;
                 p++;
               }
@@ -1366,7 +1367,7 @@ static MagickBooleanType WriteGIFImage(const ImageInfo *image_info,Image *image)
             indexes=GetIndexes(image);
             for (x=0; x < (long) image->columns; x++)
             {
-              if ((double) p->opacity >= (MaxRGB-image->fuzz))
+              if ((double) p->opacity >= (QuantumRange-image->fuzz))
                 {
                   opacity=(long) indexes[x];
                   break;
@@ -1395,7 +1396,7 @@ static MagickBooleanType WriteGIFImage(const ImageInfo *image_info,Image *image)
       *q++=(unsigned char) 0x0;
       *q++=(unsigned char) 0x0;
     }
-    if ((image->previous == (Image *) NULL) ||
+    if ((GetPreviousImageInList(image) == (Image *) NULL) ||
         (write_info->adjoin == MagickFalse))
       {
         /*
@@ -1460,8 +1461,8 @@ static MagickBooleanType WriteGIFImage(const ImageInfo *image_info,Image *image)
             }
             (void) WriteBlobByte(image,(unsigned char) 0x00);
           }
-        if ((image->previous == (Image *) NULL) &&
-            (image->next != (Image *) NULL) && (image->iterations != 1))
+        if ((GetPreviousImageInList(image) == (Image *) NULL) &&
+            (GetNextImageInList(image) != (Image *) NULL) && (image->iterations != 1))
           {
             /*
               Write Netscape Loop extension.
@@ -1519,7 +1520,7 @@ static MagickBooleanType WriteGIFImage(const ImageInfo *image_info,Image *image)
         ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
       }
     (void) WriteBlobByte(image,(unsigned char) 0x00);
-    if (image->next == (Image *) NULL)
+    if (GetNextImageInList(image) == (Image *) NULL)
       break;
     image=SyncNextImageInList(image);
     if (image->progress_monitor != (MagickProgressMonitor) NULL)
