@@ -698,7 +698,8 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   debug=IsEventLogging();
@@ -1157,10 +1158,10 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,
         indexes=GetIndexes(image);
         for (x=0; x < (long) image->columns; x++)
         {
-          q->red=(Quantum) (MaxRGB-q->red);
-          q->green=(Quantum) (MaxRGB-q->green);
-          q->blue=(Quantum) (MaxRGB-q->blue);
-          indexes[x]=(IndexPacket) (MaxRGB-indexes[x]);
+          q->red=(Quantum) (QuantumRange-q->red);
+          q->green=(Quantum) (QuantumRange-q->green);
+          q->blue=(Quantum) (QuantumRange-q->blue);
+          indexes[x]=(IndexPacket) (QuantumRange-indexes[x]);
           q++;
         }
         if (SyncImagePixels(image) == MagickFalse)
@@ -1570,7 +1571,7 @@ static MagickBooleanType WriteJPEGImage(const ImageInfo *image_info,
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
@@ -2056,10 +2057,10 @@ static MagickBooleanType WriteJPEGImage(const ImageInfo *image_info,
             /*
               Convert DirectClass packets to contiguous CMYK scanlines.
             */
-            *q++=(JSAMPLE) (ScaleQuantumToChar(MaxRGB-p->red));
-            *q++=(JSAMPLE) (ScaleQuantumToChar(MaxRGB-p->green));
-            *q++=(JSAMPLE) (ScaleQuantumToChar(MaxRGB-p->blue));
-            *q++=(JSAMPLE) (ScaleQuantumToChar(MaxRGB-indexes[x]));
+            *q++=(JSAMPLE) (ScaleQuantumToChar(QuantumRange-p->red));
+            *q++=(JSAMPLE) (ScaleQuantumToChar(QuantumRange-p->green));
+            *q++=(JSAMPLE) (ScaleQuantumToChar(QuantumRange-p->blue));
+            *q++=(JSAMPLE) (ScaleQuantumToChar(QuantumRange-indexes[x]));
             p++;
           }
           (void) jpeg_write_scanlines(&jpeg_info,scanline,1);
