@@ -151,7 +151,7 @@ static void InsertFloatRow(double *p, int y, Image * image, double Min,
     return;
   for (x = 0; x < (long) image->columns; x++)
   {
-    f = (double) MaxRGB *(*p - Min) / (Max - Min);
+    f = (double) QuantumRange *(*p - Min) / (Max - Min);
     q->red = ScaleShortToQuantum(f);
     q->green = ScaleShortToQuantum(f);
     q->blue = ScaleShortToQuantum(f);
@@ -182,9 +182,9 @@ static void InsertComplexFloatRow(double *p,int y,Image *image,double Min,
   {
     if (*p > 0)
     {
-      f = (*p / Max) * (MaxRGB - q->red);
-      if (f + q->red > MaxRGB)
-        q->red = MaxRGB;
+      f = (*p / Max) * (QuantumRange - q->red);
+      if (f + q->red > QuantumRange)
+        q->red = QuantumRange;
       else
         q->red += (int) f;
       if ((int) f / 2.0 > q->green)
@@ -194,9 +194,9 @@ static void InsertComplexFloatRow(double *p,int y,Image *image,double Min,
     }
     if (*p < 0)
     {
-      f = (*p / Max) * (MaxRGB - q->blue);
-      if (f + q->blue > MaxRGB)
-        q->blue = MaxRGB;
+      f = (*p / Max) * (QuantumRange - q->blue);
+      if (f + q->blue > QuantumRange)
+        q->blue = QuantumRange;
       else
         q->blue += (int) f;
       if ((int) f / 2.0 > q->green)
@@ -251,7 +251,7 @@ static double ReadBlobLSBdouble(Image *image)
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if (ReadBlob(image, 8, (unsigned char *) &buffer) == 0)
     return(0.0);
   if (*(char *) &lsb_first == 1)
