@@ -448,7 +448,8 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   image=AllocateImage(image_info);
@@ -1212,7 +1213,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
           Allocate next image structure.
         */
         AllocateNextImage(image_info,image);
-        if (image->next == (Image *) NULL)
+        if (GetNextImageInList(image) == (Image *) NULL)
           {
             image=DestroyImageList(image);
             return((Image *) NULL);
@@ -1547,7 +1548,7 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
@@ -1649,7 +1650,7 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
             image->page.x,image->page.y);
           (void) WriteBlobString(image,buffer);
         }
-    if ((image->next != (Image *) NULL) || (image->previous != (Image *) NULL))
+    if ((GetNextImageInList(image) != (Image *) NULL) || (GetPreviousImageInList(image) != (Image *) NULL))
       {
         if (image->scene == 0)
           (void) FormatMagickString(buffer,MaxTextExtent,
@@ -2050,7 +2051,7 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
     }
     pixels=(unsigned char *) RelinquishMagickMemory(pixels);
     compress_pixels=(unsigned char *) RelinquishMagickMemory(compress_pixels);
-    if (image->next == (Image *) NULL)
+    if (GetNextImageInList(image) == (Image *) NULL)
       break;
     image=SyncNextImageInList(image);
     if (image->progress_monitor != (MagickProgressMonitor) NULL)
