@@ -152,7 +152,8 @@ static Image *ReadMPEGImage(const ImageInfo *image_info,
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   image=AllocateImage(image_info);
@@ -424,7 +425,7 @@ static MagickBooleanType WriteMPEGParameterFiles(const ImageInfo *image_info,
   (void) fprintf(file,"%s.log\n",basename);  /* statistics log */
   (void) fprintf(file,"1\n");  /* input picture file format */
   count=0;
-  for (p=image; p != (Image *) NULL; p=p->next)
+  for (p=image; p != (Image *) NULL; p=GetNextImageInList(p))
     count+=Max((p->delay+1)/3,1);
   (void) fprintf(file,"%lu\n",(unsigned long) count); /* number of frames */
   (void) fprintf(file,"0\n");  /* number of first frame */
@@ -565,7 +566,7 @@ static MagickBooleanType WriteMPEGImage(const ImageInfo *image_info,Image *image
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
@@ -582,7 +583,7 @@ static MagickBooleanType WriteMPEGImage(const ImageInfo *image_info,Image *image
     if ((image->page.x != next_image->page.x) ||
         (image->page.y != next_image->page.y))
       break;
-    next_image=next_image->next;
+    next_image=GetNextImageInList(next_image);
   }
   if (next_image != (Image *) NULL)
     {
@@ -618,7 +619,7 @@ static MagickBooleanType WriteMPEGImage(const ImageInfo *image_info,Image *image
     }
   count=0;
   write_info->interlace=PlaneInterlace;
-  for (p=coalesce_image; p != (Image *) NULL; p=p->next)
+  for (p=coalesce_image; p != (Image *) NULL; p=GetNextImageInList(p))
   {
     char
       previous_image[MaxTextExtent];
@@ -694,7 +695,7 @@ static MagickBooleanType WriteMPEGImage(const ImageInfo *image_info,Image *image
     Free resources.
   */
   count=0;
-  for (p=coalesce_image; p != (Image *) NULL; p=p->next)
+  for (p=coalesce_image; p != (Image *) NULL; p=GetNextImageInList(p))
   {
     for (i=0; i < (long) Max((p->delay+1)/3,1); i++)
     {
