@@ -183,7 +183,7 @@ static MagickBooleanType DecodeImage(Image *image,unsigned char *luma,
   assert(image != (const Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   assert(luma != (unsigned char *) NULL);
   assert(chroma1 != (unsigned char *) NULL);
   assert(chroma2 != (unsigned char *) NULL);
@@ -488,7 +488,8 @@ static Image *ReadPCDImage(const ImageInfo *image_info,ExceptionInfo *exception)
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   image=AllocateImage(image_info);
@@ -650,7 +651,7 @@ static Image *ReadPCDImage(const ImageInfo *image_info,ExceptionInfo *exception)
               Allocate next image structure.
             */
             AllocateNextImage(image_info,image);
-            if (image->next == (Image *) NULL)
+            if (GetNextImageInList(image) == (Image *) NULL)
               {
                 image=DestroyImageList(image);
                 return((Image *) NULL);
@@ -671,8 +672,7 @@ static Image *ReadPCDImage(const ImageInfo *image_info,ExceptionInfo *exception)
       chroma2=(unsigned char *) RelinquishMagickMemory(chroma2);
       chroma1=(unsigned char *) RelinquishMagickMemory(chroma1);
       luma=(unsigned char *) RelinquishMagickMemory(luma);
-      while (image->previous != (Image *) NULL)
-        image=image->previous;
+      image=GetFirstImageInList(image);
       overview_image=OverviewImage(image_info,image,exception);
       return(overview_image);
     }
@@ -1042,7 +1042,7 @@ static MagickBooleanType WritePCDImage(const ImageInfo *image_info,Image *image)
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   pcd_image=image;
   if (image->columns < image->rows)
     {
