@@ -250,7 +250,8 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   image=AllocateImage(image_info);
@@ -413,9 +414,9 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
               image->colormap[0].red=0;
               image->colormap[0].green=0;
               image->colormap[0].blue=0;
-              image->colormap[1].red=MaxRGB;
-              image->colormap[1].green=MaxRGB;
-              image->colormap[1].blue=MaxRGB;
+              image->colormap[1].red=QuantumRange;
+              image->colormap[1].green=QuantumRange;
+              image->colormap[1].blue=QuantumRange;
             }
           else
             if (image->colors > 16)
@@ -573,7 +574,7 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
             q->green=ScaleCharToQuantum(*r++);
             q->blue=ScaleCharToQuantum(*r++);
             if (image->matte != MagickFalse)
-              q->opacity=(Quantum) (MaxRGB-ScaleCharToQuantum(*r++));
+              q->opacity=(Quantum) (QuantumRange-ScaleCharToQuantum(*r++));
           }
         q++;
       }
@@ -619,7 +620,7 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
           Allocate next image structure.
         */
         AllocateNextImage(image_info,image);
-        if (image->next == (Image *) NULL)
+        if (GetNextImageInList(image) == (Image *) NULL)
           {
             image=DestroyImageList(image);
             return((Image *) NULL);
@@ -830,14 +831,14 @@ static MagickBooleanType WritePCXImage(const ImageInfo *image_info,Image *image)
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
   (void) SetImageColorspace(image,RGBColorspace);
   page_table=(MagickOffsetType *) NULL;
   if ((LocaleCompare(image_info->magick,"DCX") == 0) ||
-      ((image->next != (Image *) NULL) && (image_info->adjoin != MagickFalse)))
+      ((GetNextImageInList(image) != (Image *) NULL) && (image_info->adjoin != MagickFalse)))
     {
       /*
         Write the DCX page table.
@@ -994,7 +995,7 @@ static MagickBooleanType WritePCXImage(const ImageInfo *image_info,Image *image)
               {
                 for (x=(long) pcx_info.bytes_per_line; x > 0; x--)
                 {
-                  *q++=ScaleQuantumToChar(MaxRGB-p->opacity);
+                  *q++=ScaleQuantumToChar(QuantumRange-p->opacity);
                   p++;
                 }
                 break;
@@ -1046,7 +1047,7 @@ static MagickBooleanType WritePCXImage(const ImageInfo *image_info,Image *image)
           /*
             Convert PseudoClass image to a PCX monochrome image.
           */
-          polarity=PixelIntensityToQuantum(&image->colormap[0]) < (MaxRGB/2);
+          polarity=PixelIntensityToQuantum(&image->colormap[0]) < (QuantumRange/2);
           if (image->colors == 2)
             polarity=PixelIntensityToQuantum(&image->colormap[0]) <
               PixelIntensityToQuantum(&image->colormap[1]);
@@ -1092,7 +1093,7 @@ static MagickBooleanType WritePCXImage(const ImageInfo *image_info,Image *image)
     (void) WriteBlob(image,3*256,pcx_colormap);
     pcx_pixels=(unsigned char *) RelinquishMagickMemory(pcx_pixels);
     pcx_colormap=(unsigned char *) RelinquishMagickMemory(pcx_colormap);
-    if (image->next == (Image *) NULL)
+    if (GetNextImageInList(image) == (Image *) NULL)
       break;
     image=SyncNextImageInList(image);
     if (image->progress_monitor != (MagickProgressMonitor) NULL)
