@@ -150,7 +150,7 @@ static Image *ReadPlasmaImage(const ImageInfo *image_info,
       break;
     for (x=0; x < (long) image->columns; x++)
     {
-      q->opacity=(Quantum) (MaxRGB/2);
+      q->opacity=(Quantum) (QuantumRange/2);
       q++;
     }
     if (SyncImagePixels(image) == MagickFalse)
