@@ -276,7 +276,8 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   image=AllocateImage(image_info);
@@ -340,7 +341,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 }
           }
       }
-    if ((image->storage_class != PseudoClass) || (max_value > MaxRGB))
+    if ((image->storage_class != PseudoClass) || (max_value > QuantumRange))
       {
         /*
           Compute pixel scaling table.
@@ -695,7 +696,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           Allocate next image structure.
         */
         AllocateNextImage(image_info,image);
-        if (image->next == (Image *) NULL)
+        if (GetNextImageInList(image) == (Image *) NULL)
           {
             image=DestroyImageList(image);
             return((Image *) NULL);
@@ -871,7 +872,7 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
@@ -948,7 +949,7 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
         */
         (void) SetImageType(image,BilevelType);
         polarity=(IndexPacket)
-          (PixelIntensityToQuantum(&image->colormap[0]) < (MaxRGB/2));
+          (PixelIntensityToQuantum(&image->colormap[0]) < (QuantumRange/2));
         if (image->colors == 2)
           polarity=(IndexPacket)
             (PixelIntensityToQuantum(&image->colormap[0]) <
@@ -1095,7 +1096,7 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
         */
         (void) SetImageType(image,BilevelType);
         polarity=(IndexPacket)
-          (PixelIntensityToQuantum(&image->colormap[0]) < (MaxRGB/2));
+          (PixelIntensityToQuantum(&image->colormap[0]) < (QuantumRange/2));
         if (image->colors == 2)
           polarity=(IndexPacket)
             (PixelIntensityToQuantum(&image->colormap[0]) <
@@ -1376,7 +1377,7 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
         break;
       }
     }
-    if (image->next == (Image *) NULL)
+    if (GetNextImageInList(image) == (Image *) NULL)
       break;
     image=SyncNextImageInList(image);
     if (image->progress_monitor != (MagickProgressMonitor) NULL)
