@@ -250,7 +250,8 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   image=AllocateImage(image_info);
@@ -1003,7 +1004,7 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
@@ -1098,7 +1099,7 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
         bounds.x2=(double) geometry.x+x_scale;
         bounds.y2=(double) geometry.y+(geometry.height+text_size);
         if ((image_info->adjoin != MagickFalse) &&
-            (image->next != (Image *) NULL))
+            (GetNextImageInList(image) != (Image *) NULL))
           (void) strcpy(buffer,"%%%%BoundingBox: (atend)\n");
         else
           {
@@ -1158,7 +1159,7 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
             */
             (void) SetImageType(preview_image,BilevelType);
             polarity=(IndexPacket) (PixelIntensityToQuantum(
-              &preview_image->colormap[0]) < (MaxRGB/2));
+              &preview_image->colormap[0]) < (QuantumRange/2));
             if (preview_image->colors == 2)
               polarity=(IndexPacket)
                 (PixelIntensityToQuantum(&preview_image->colormap[0]) >
@@ -1345,7 +1346,7 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
             */
             (void) SetImageType(image,BilevelType);
             polarity=(IndexPacket) (PixelIntensityToQuantum(
-              &image->colormap[0]) < (MaxRGB/2));
+              &image->colormap[0]) < (QuantumRange/2));
             if (image->colors == 2)
               polarity=(IndexPacket)
                 (PixelIntensityToQuantum(&image->colormap[1]) <
@@ -1410,7 +1411,8 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
           (void) WriteBlobByte(image,'\n');
       }
     else
-      if ((image->storage_class == DirectClass) || (image->matte != MagickFalse))
+      if ((image->storage_class == DirectClass) ||
+          (image->matte != MagickFalse))
         {
           /*
             Dump DirectClass image.
@@ -1641,7 +1643,7 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
     if (LocaleCompare(image_info->magick,"PS") != 0)
       (void) WriteBlobString(image,"end\n");
     (void) WriteBlobString(image,"%%PageTrailer\n");
-    if (image->next == (Image *) NULL)
+    if (GetNextImageInList(image) == (Image *) NULL)
       break;
     image=SyncNextImageInList(image);
     if (image->progress_monitor != (MagickProgressMonitor) NULL)
