@@ -127,7 +127,8 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   image=AllocateImage(image_info);
@@ -201,7 +202,7 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         }
         for (y=0; y < (long) image->rows; y++)
         {
-          if ((y > 0) || (image->previous == (Image *) NULL))
+          if ((y > 0) || (GetPreviousImageInList(image) == (Image *) NULL))
             {
               count=ReadBlob(image,packet_size*image->extract_info.width,
                 scanline);
@@ -253,7 +254,7 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         }
         for (y=0; y < (long) image->rows; y++)
         {
-          if ((y > 0) || (image->previous == (Image *) NULL))
+          if ((y > 0) || (GetPreviousImageInList(image) == (Image *) NULL))
             {
               count=ReadBlob(image,packet_size*image->extract_info.width,
                 scanline);
@@ -336,7 +337,7 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         span=image->rows*(image->matte != MagickFalse ? 4 : 3);
         for (y=0; y < (long) image->rows; y++)
         {
-          if ((y > 0) || (image->previous == (Image *) NULL))
+          if ((y > 0) || (GetPreviousImageInList(image) == (Image *) NULL))
             {
               count=ReadBlob(image,packet_size*image->extract_info.width,
                 scanline);
@@ -546,7 +547,7 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
           Allocate next image structure.
         */
         AllocateNextImage(image_info,image);
-        if (image->next == (Image *) NULL)
+        if (GetNextImageInList(image) == (Image *) NULL)
           {
             image=DestroyImageList(image);
             return((Image *) NULL);
@@ -702,7 +703,7 @@ static MagickBooleanType WriteRGBImage(const ImageInfo *image_info,Image *image)
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   depth=GetImageQuantumDepth(image,MagickTrue);
   packet_size=(size_t) (3*depth/8);
   if ((LocaleCompare(image_info->magick,"RGBA") == 0) ||
@@ -918,7 +919,7 @@ static MagickBooleanType WriteRGBImage(const ImageInfo *image_info,Image *image)
         break;
       }
     }
-    if (image->next == (Image *) NULL)
+    if (GetNextImageInList(image) == (Image *) NULL)
       break;
     image=SyncNextImageInList(image);
     if (image->progress_monitor != (MagickProgressMonitor) NULL)
