@@ -172,7 +172,8 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   image=AllocateImage(image_info);
@@ -407,7 +408,7 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
               pixel.green=ScaleCharToQuantum(ReadBlobByte(image));
               pixel.red=ScaleCharToQuantum(ReadBlobByte(image));
               if (tga_info.bits_per_pixel == 32)
-                pixel.opacity=MaxRGB-ScaleCharToQuantum(ReadBlobByte(image));
+                pixel.opacity=QuantumRange-ScaleCharToQuantum(ReadBlobByte(image));
               break;
             }
           }
@@ -468,7 +469,7 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
           Allocate next image structure.
         */
         AllocateNextImage(image_info,image);
-        if (image->next == (Image *) NULL)
+        if (GetNextImageInList(image) == (Image *) NULL)
           {
             image=DestroyImageList(image);
             return((Image *) NULL);
@@ -672,7 +673,7 @@ static MagickBooleanType WriteTGAImage(const ImageInfo *image_info,Image *image)
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
@@ -698,7 +699,10 @@ static MagickBooleanType WriteTGAImage(const ImageInfo *image_info,Image *image)
     targa_info.bits_per_pixel=8;
     targa_info.attributes=0;
     if ((image_info->type != TrueColorType) &&
-		    (IsGrayImage(image,&image->exception) != MagickFalse))
+        (image_info->type != TrueColorMatteType) &&
+        (image_info->type != PaletteType) &&
+        (image->matte == MagickFalse) &&
+        (IsGrayImage(image,&image->exception) != MagickFalse))
       targa_info.image_type=TargaMonochrome;
     else
       if ((image->storage_class == DirectClass) || (image->colors > 256))
@@ -791,7 +795,7 @@ static MagickBooleanType WriteTGAImage(const ImageInfo *image_info,Image *image)
               *q++=ScaleQuantumToChar(p->green);
               *q++=ScaleQuantumToChar(p->red);
               if (image->matte != MagickFalse)
-                *q++=MaxRGB-ScaleQuantumToChar(p->opacity);
+                *q++=QuantumRange-ScaleQuantumToChar(p->opacity);
               if (image->colorspace == CMYKColorspace)
                 *q++=ScaleQuantumToChar(indexes[x]);
             }
@@ -809,7 +813,7 @@ static MagickBooleanType WriteTGAImage(const ImageInfo *image_info,Image *image)
           }
     }
     targa_pixels=(unsigned char *) RelinquishMagickMemory(targa_pixels);
-    if (image->next == (Image *) NULL)
+    if (GetNextImageInList(image) == (Image *) NULL)
       break;
     image=SyncNextImageInList(image);
     if (image->progress_monitor != (MagickProgressMonitor) NULL)
