@@ -247,7 +247,6 @@ static int32 TIFFReadPixels(TIFF *tiff,unsigned long bits_per_sample,
     status;
 
   status=TIFFReadScanline(tiff,scanline,(uint32) row,sample);
-    return(status);
   return(status);
 }
 
@@ -328,6 +327,9 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
   MagickSizeType
     number_pixels;
 
+  QuantumType
+    quantum_type;
+
   register long
     x;
 
@@ -337,6 +339,9 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
   register PixelPacket
     *q;
 
+  size_t
+    pad;
+
   TIFF
     *tiff;
 
@@ -370,13 +375,17 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
     *profile,
     *scanline;
 
+  unsigned long
+    lsb_first;
+
   /*
     Open image.
   */
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   image=AllocateImage(image_info);
@@ -484,14 +493,14 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
           }
         }
       }
+    lsb_first=1;
+    image->endian=MSBEndian;
+    if ((int) (*(char *) &lsb_first) != 0)
+      image->endian=LSBEndian;
     if (photometric == PHOTOMETRIC_CIELAB)
       image->colorspace=LABColorspace;
     if (photometric == PHOTOMETRIC_SEPARATED)
       image->colorspace=CMYKColorspace;
-    if (endian == FILLORDER_MSB2LSB)
-      image->endian=LSBEndian;
-    if (endian == FILLORDER_LSB2MSB)
-      image->endian=MSBEndian;
     (void) TIFFGetFieldDefaulted(tiff,TIFFTAG_SAMPLESPERPIXEL,
       &samples_per_pixel);
     (void) TIFFGetFieldDefaulted(tiff,TIFFTAG_RESOLUTIONUNIT,&units);
@@ -688,7 +697,7 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
           {
             for (i=0; i < (long) image->colors; i++)
             {
-              quantum=MaxRGB-ScaleXToQuantum(i,Max(image->colors-1,1));
+              quantum=QuantumRange-ScaleXToQuantum(i,Max(image->colors-1,1));
               image->colormap[i].red=quantum;
               image->colormap[i].green=quantum;
               image->colormap[i].blue=quantum;
@@ -725,6 +734,27 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
             break;
           }
         }
+        quantum_type=IndexQuark;
+        pad=samples_per_pixel-1;
+        if (image->matte != MagickFalse)
+          {
+            if (photometric != PHOTOMETRIC_PALETTE)
+              {
+                quantum_type=GrayAlphaQuark;
+                pad=samples_per_pixel-2;
+              }
+            else
+              {
+                quantum_type=IndexAlphaQuark;
+                pad=samples_per_pixel-2;
+              }
+          }
+        else
+          if (photometric != PHOTOMETRIC_PALETTE)
+            {
+              quantum_type=GrayQuark;
+              pad=samples_per_pixel-1;
+            }
         for (y=0; y < (long) image->rows; y++)
         {
           int
@@ -739,22 +769,7 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
           /*
             Transfer image scanline.
           */
-          if (image->matte != MagickFalse)
-            {
-              if (photometric != PHOTOMETRIC_PALETTE)
-                (void) ExportQuantumPixels(image,GrayAlphaQuark,(size_t)
-                  (samples_per_pixel-2),scanline);
-              else
-                (void) ExportQuantumPixels(image,IndexAlphaQuark,(size_t)
-                  (samples_per_pixel-2),scanline);
-            }
-          else
-            if (photometric != PHOTOMETRIC_PALETTE)
-              (void) ExportQuantumPixels(image,GrayQuark,(size_t)
-                (samples_per_pixel-1),scanline);
-            else
-              (void) ExportQuantumPixels(image,IndexQuark,(size_t)
-                (samples_per_pixel-1),scanline);
+          (void) ExportQuantumPixels(image,quantum_type,pad,scanline);
           if (SyncImagePixels(image) == MagickFalse)
             break;
           if (image->previous == (Image *) NULL)
@@ -782,6 +797,27 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
             TIFFClose(tiff);
             ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
           }
+        quantum_type=RGBQuantum;
+        pad=samples_per_pixel-3;
+        if (image->colorspace == CMYKColorspace)
+          {
+            if (image->matte == MagickFalse)
+              {
+                quantum_type=CMYKQuantum;
+                pad=samples_per_pixel-4;
+              }
+            else
+              {
+                quantum_type=CMYKAQuantum;
+                pad=samples_per_pixel-5;
+              }
+          }
+        else
+          if (image->matte != MagickFalse)
+            {
+              quantum_type=RGBAQuantum;
+              pad=samples_per_pixel-4;
+            }
         for (y=0; y < (long) image->rows; y++)
         {
           int
@@ -812,22 +848,7 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
           q=SetImagePixels(image,0,y,image->columns,1);
           if (q == (PixelPacket *) NULL)
             break;
-          if (image->colorspace == CMYKColorspace)
-            {
-              if (image->matte == MagickFalse)
-                (void) ExportQuantumPixels(image,CMYKQuantum,(size_t)
-                  (samples_per_pixel-4),scanline);
-              else
-                (void) ExportQuantumPixels(image,CMYKAQuantum,(size_t)
-                  (samples_per_pixel-5),scanline);
-            }
-          else
-            if (image->matte == MagickFalse)
-              (void) ExportQuantumPixels(image,RGBQuantum,(size_t)
-                (samples_per_pixel-3),scanline);
-            else
-              (void) ExportQuantumPixels(image,RGBAQuantum,(size_t)
-                (samples_per_pixel-4),scanline);
+          (void) ExportQuantumPixels(image,quantum_type,pad,scanline);
           if (SyncImagePixels(image) == MagickFalse)
             break;
           if (image->previous == (Image *) NULL)
@@ -1084,7 +1105,7 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
             break;
           for (x=0; x < (long) image->columns; x++)
           {
-            gamma=((MagickRealType) MaxRGB-q->opacity)/MaxRGB;
+            gamma=((MagickRealType) QuantumRange-q->opacity)/QuantumRange;
             gamma=1.0/(fabs(gamma) <= MagickEpsilon ? 1.0 : gamma);
             q->red=(Quantum) (gamma*q->red);
             q->green=(Quantum) (gamma*q->green);
@@ -1095,6 +1116,9 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
             break;
         }
       }
+    image->endian=MSBEndian;
+    if (endian == FILLORDER_LSB2MSB)
+      image->endian=LSBEndian;
     /*
       Proceed to next image.
     */
@@ -1108,7 +1132,7 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
           Allocate next image structure.
         */
         AllocateNextImage(image_info,image);
-        if (image->next == (Image *) NULL)
+        if (GetNextImageInList(image) == (Image *) NULL)
           {
             image=DestroyImageList(image);
             return((Image *) NULL);
@@ -1279,16 +1303,15 @@ static MagickBooleanType WritePTIFImage(const ImageInfo *image_info,
   {
     pyramid_image->next=ResizeImage(image,pyramid_image->columns/2,
       pyramid_image->rows/2,TriangleFilter,1.0,&image->exception);
-    if (pyramid_image->next == (Image *) NULL)
+    if (GetNextImageInList(pyramid_image) == (Image *) NULL)
       {
         pyramid_image=DestroyImageList(pyramid_image);
         return(MagickFalse);
       }
     pyramid_image->next->previous=pyramid_image;
-    pyramid_image=pyramid_image->next;
+    pyramid_image=GetNextImageInList(pyramid_image);
   } while ((pyramid_image->columns > 64) && (pyramid_image->rows > 64));
-  while (pyramid_image->previous != (Image *) NULL)
-    pyramid_image=pyramid_image->previous;
+  pyramid_image=GetFirstImageInList(pyramid_image);
   /*
     Write pyramid-encoded TIFF image.
   */
@@ -1447,6 +1470,7 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
   uint16
     bits_per_sample,
     compress_tag,
+    endian,
     photometric;
 
   unsigned char
@@ -1464,7 +1488,7 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   status=OpenBlob(image_info,image,IOBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
@@ -1484,7 +1508,7 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
       Initialize TIFF fields.
     */
     if (LocaleCompare(image_info->magick,"PTIF") == 0)
-      if (image->previous != (Image *) NULL)
+      if (GetPreviousImageInList(image) != (Image *) NULL)
         (void) TIFFSetField(tiff,TIFFTAG_SUBFILETYPE,FILETYPE_REDUCEDIMAGE);
     (void) TIFFSetField(tiff,TIFFTAG_IMAGELENGTH,(uint32) image->rows);
     (void) TIFFSetField(tiff,TIFFTAG_IMAGEWIDTH,(uint32) image->columns);
@@ -1665,26 +1689,26 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
     {
       case LSBEndian:
       {
-        (void) TIFFSetField(tiff,TIFFTAG_FILLORDER,FILLORDER_MSB2LSB);
+        endian=FILLORDER_LSB2MSB;
         break;
       }
       case MSBEndian:
       {
-        (void) TIFFSetField(tiff,TIFFTAG_FILLORDER,FILLORDER_LSB2MSB);
+        endian=FILLORDER_MSB2LSB;
         break;
       }
       case UndefinedEndian:
       default:
       {
-        lsb_first=1;
-        image->endian=(*(char *) &lsb_first != 0) ? LSBEndian : MSBEndian;
-        if (image->endian == MSBEndian)
-          (void) TIFFSetField(tiff,TIFFTAG_FILLORDER,FILLORDER_LSB2MSB);
-        else
-          (void) TIFFSetField(tiff,TIFFTAG_FILLORDER,FILLORDER_MSB2LSB);
+        (void) TIFFGetFieldDefaulted(tiff,TIFFTAG_FILLORDER,&endian);
         break;
       }
     }
+    lsb_first=1;                                                                
+    image->endian=MSBEndian;
+    if ((int) (*(char *) &lsb_first) != 0)
+      image->endian=LSBEndian;
+    (void) TIFFSetField(tiff,TIFFTAG_FILLORDER,endian);
     (void) TIFFSetField(tiff,TIFFTAG_ORIENTATION,ORIENTATION_TOPLEFT);
     (void) TIFFSetField(tiff,TIFFTAG_PLANARCONFIG,PLANARCONFIG_CONTIG);
     if (photometric == PHOTOMETRIC_RGB)
@@ -2089,7 +2113,10 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
     if (image_info->verbose == MagickTrue)
       TIFFPrintDirectory(tiff,stdout,MagickFalse);
     (void) TIFFWriteDirectory(tiff);
-    if (image->next == (Image *) NULL)
+    image->endian=MSBEndian;
+    if (endian == FILLORDER_LSB2MSB)
+      image->endian=LSBEndian;
+    if (GetNextImageInList(image) == (Image *) NULL)
       break;
     image=SyncNextImageInList(image);
     if (image->progress_monitor != (MagickProgressMonitor) NULL)
