@@ -186,7 +186,8 @@ static Image *ReadTEXTImage(const ImageInfo *image_info,
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   image=AllocateImage(image_info);
@@ -302,7 +303,7 @@ static Image *ReadTEXTImage(const ImageInfo *image_info,
     *draw_info->text='\0';
     offset=2*page.y;
     AllocateNextImage(image_info,image);
-    if (image->next == (Image *) NULL)
+    if (GetNextImageInList(image) == (Image *) NULL)
       {
         image=DestroyImageList(image);
         return((Image *) NULL);
@@ -405,7 +406,8 @@ static Image *ReadTXTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   image=AllocateImage(image_info);
@@ -425,7 +427,7 @@ static Image *ReadTXTImage(const ImageInfo *image_info,ExceptionInfo *exception)
     image->colorspace=CMYKColorspace;
   image->matte=(MagickBooleanType) (strchr(format,'A') != (char *) NULL);
   scale=(Quantum *) NULL;
-  if (max_value != MaxRGB)
+  if (max_value != QuantumRange)
     {
       /*
         Compute pixel scaling table.
@@ -606,7 +608,7 @@ static MagickBooleanType WriteTXTImage(const ImageInfo *image_info,Image *image)
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   status=OpenBlob(image_info,image,WriteBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
@@ -618,7 +620,7 @@ static MagickBooleanType WriteTXTImage(const ImageInfo *image_info,Image *image)
     (void) ConcatenateMagickString(format,"A",MaxTextExtent);
   (void) FormatMagickString(buffer,MaxTextExtent,
     "# ImageMagick pixel enumeration: %lu,%lu,%lu,%s\n",image->columns,
-    image->rows,image->depth == QuantumDepth ? (unsigned long) MaxRGB :
+    image->rows,image->depth == QuantumDepth ? (unsigned long) QuantumRange :
     (1L << image->depth)-1,format);
   (void) WriteBlobString(image,buffer);
   scene=0;
@@ -658,7 +660,7 @@ static MagickBooleanType WriteTXTImage(const ImageInfo *image_info,Image *image)
               break;
           }
     }
-    if (image->next == (Image *) NULL)
+    if (GetNextImageInList(image) == (Image *) NULL)
       break;
     image=SyncNextImageInList(image);
     if (image->progress_monitor != (MagickProgressMonitor) NULL)
