@@ -97,7 +97,7 @@ MagickExport MagickBooleanType CloneImageAttributes(Image *image,
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   assert(clone_image != (const Image *) NULL);
   assert(clone_image->signature == MagickSignature);
   if (clone_image->attributes == (void *) NULL)
@@ -142,7 +142,7 @@ MagickExport MagickBooleanType DeleteImageAttribute(Image *image,
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if (image->attributes == (void *) NULL)
     return(MagickFalse);
   return(RemoveNodeFromSplayTree(image->attributes,key));
@@ -176,7 +176,7 @@ MagickExport void DestroyImageAttributes(Image *image)
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if (image->attributes != (void *) NULL)
     image->attributes=DestroySplayTree(image->attributes);
 }
@@ -494,121 +494,249 @@ typedef struct _TagInfo
 static TagInfo
   tag_table[] =
   {
-    {  0x1, (char *) "InteroperabilityIndex"},
-    {  0x2, (char *) "InteroperabilityVersion"},
-    {  0x100, (char *) "ImageWidth"},
-    {  0x101, (char *) "ImageLength"},
-    {  0x102, (char *) "BitsPerSample"},
-    {  0x103, (char *) "Compression"},
-    {  0x106, (char *) "PhotometricInterpretation"},
-    {  0x10a, (char *) "FillOrder"},
-    {  0x10d, (char *) "DocumentName"},
-    {  0x10e, (char *) "ImageDescription"},
-    {  0x10f, (char *) "Make"},
-    {  0x110, (char *) "Model"},
-    {  0x111, (char *) "StripOffsets"},
-    {  0x112, (char *) "Orientation"},
-    {  0x115, (char *) "SamplesPerPixel"},
-    {  0x116, (char *) "RowsPerStrip"},
-    {  0x117, (char *) "StripByteCounts"},
-    {  0x11a, (char *) "XResolution"},
-    {  0x11b, (char *) "YResolution"},
-    {  0x11c, (char *) "PlanarConfiguration"},
-    {  0x128, (char *) "ResolutionUnit"},
-    {  0x12d, (char *) "TransferFunction"},
-    {  0x131, (char *) "Software"},
-    {  0x132, (char *) "DateTime"},
-    {  0x13b, (char *) "Artist"},
-    {  0x13e, (char *) "WhitePoint"},
-    {  0x13f, (char *) "PrimaryChromaticities"},
-    {  0x156, (char *) "TransferRange"},
-    {  0x200, (char *) "JPEGProc"},
-    {  0x201, (char *) "JPEGInterchangeFormat"},
-    {  0x202, (char *) "JPEGInterchangeFormatLength"},
-    {  0x211, (char *) "YCbCrCoefficients"},
-    {  0x212, (char *) "YCbCrSubSampling"},
-    {  0x213, (char *) "YCbCrPositioning"},
-    {  0x214, (char *) "ReferenceBlackWhite"},
-    {  0x1000, (char *) "RelatedImageFileFormat"},
-    {  0x1001, (char *) "RelatedImageLength"},
-    {  0x1002, (char *) "RelatedImageWidth"},
-    {  0x828d, (char *) "CFARepeatPatternDim"},
-    {  0x828e, (char *) "CFAPattern"},
-    {  0x828f, (char *) "BatteryLevel"},
-    {  0x8298, (char *) "Copyright"},
-    {  0x829a, (char *) "ExposureTime"},
-    {  0x829d, (char *) "FNumber"},
-    {  0x83Bb, (char *) "IPTC/NAA"},
-    {  0x8769, (char *) "ExifOffset"},
-    {  0x8773, (char *) "InterColorProfile"},
-    {  0x8822, (char *) "ExposureProgram"},
-    {  0x8824, (char *) "SpectralSensitivity"},
-    {  0x8825, (char *) "GPSInfo"},
-    {  0x8827, (char *) "ISOSpeedRatings"},
-    {  0x8828, (char *) "OECF"},
-    {  0x8829, (char *) "Interlace"},
-    {  0x882a, (char *) "TimeZoneOffset"},
-    {  0x882b, (char *) "SelfTimerMode"},
-    {  0x9000, (char *) "ExifVersion"},
-    {  0x9003, (char *) "DateTimeOriginal"},
-    {  0x9004, (char *) "DateTimeDigitized"},
-    {  0x9101, (char *) "ComponentsConfiguration"},
-    {  0x9102, (char *) "CompressedBitsPerPixel"},
-    {  0x9201, (char *) "ShutterSpeedValue"},
-    {  0x9202, (char *) "ApertureValue"},
-    {  0x9203, (char *) "BrightnessValue"},
-    {  0x9204, (char *) "ExposureBiasValue"},
-    {  0x9205, (char *) "MaxApertureValue"},
-    {  0x9206, (char *) "SubjectDistance"},
-    {  0x9207, (char *) "MeteringMode"},
-    {  0x9208, (char *) "LightSource"},
-    {  0x9209, (char *) "Flash"},
-    {  0x920a, (char *) "FocalLength"},
-    {  0x920b, (char *) "FlashEnergy"},
-    {  0x920c, (char *) "SpatialFrequencyResponse"},
-    {  0x920d, (char *) "Noise"},
-    {  0x9211, (char *) "ImageNumber"},
-    {  0x9212, (char *) "SecurityClassification"},
-    {  0x9213, (char *) "ImageHistory"},
-    {  0x9214, (char *) "SubjectArea"},
-    {  0x9215, (char *) "ExposureIndex"},
-    {  0x9216, (char *) "TIFF/EPStandardID"},
-    {  0x927c, (char *) "MakerNote"},
-    {  0x9286, (char *) "UserComment"},
-    {  0x9290, (char *) "SubSecTime"},
-    {  0x9291, (char *) "SubSecTimeOriginal"},
-    {  0x9292, (char *) "SubSecTimeDigitized"},
-    {  0xA000, (char *) "FlashPixVersion"},
-    {  0xA001, (char *) "ColorSpace"},
-    {  0xA002, (char *) "ExifImageWidth"},
-    {  0xA003, (char *) "ExifImageLength"},
-    {  0xA004, (char *) "RelatedSoundFile"},
-    {  0xA005, (char *) "InteroperabilityOffset"},
-    {  0xA20b, (char *) "FlashEnergy"},
-    {  0xA20c, (char *) "SpatialFrequencyResponse"},
-    {  0xA20e, (char *) "FocalPlaneXResolution"},
-    {  0xA20f, (char *) "FocalPlaneYResolution"},
-    {  0xA210, (char *) "FocalPlaneResolutionUnit"},
-    {  0xA214, (char *) "SubjectLocation"},
-    {  0xA215, (char *) "ExposureIndex"},
-    {  0xA217, (char *) "SensingMethod"},
-    {  0xA300, (char *) "FileSource"},
-    {  0xA301, (char *) "SceneType"},
-    {  0xA302, (char *) "CFAPattern"},
-    {  0xA401, (char *) "CustomRendered"},
-    {  0xA402, (char *) "ExposureMode"},
-    {  0xA403, (char *) "WhiteBalance"},
-    {  0xA404, (char *) "DigitalZoomRatio"},
-    {  0xA405, (char *) "FocalLengthIn35mmFilm"},
-    {  0xA406, (char *) "SceneCaptureType"},
-    {  0xA407, (char *) "GainControl"},
-    {  0xA408, (char *) "Contrast"},
-    {  0xA409, (char *) "Saturation"},
-    {  0xA40a, (char *) "Sharpness"},
-    {  0xA40b, (char *) "DeviceSettingDescription"},
-    {  0xA40c, (char *) "SubjectDistanceRange"},
-    {  0xA420, (char *) "ImageUniqueID"},
-    {  0xC4a5, (char *) "PrintImageMatching" },
+    {  0x001, (char *) "InteroperabilityIndex" },
+    {  0x002, (char *) "InteroperabilityVersion" },
+    {  0x100, (char *) "ImageWidth" },
+    {  0x101, (char *) "ImageLength" },
+    {  0x102, (char *) "BitsPerSample" },
+    {  0x103, (char *) "Compression" },
+    {  0x106, (char *) "PhotometricInterpretation" },
+    {  0x10a, (char *) "FillOrder" },
+    {  0x10d, (char *) "DocumentName" },
+    {  0x10e, (char *) "ImageDescription" },
+    {  0x10f, (char *) "Make" },
+    {  0x110, (char *) "Model" },
+    {  0x111, (char *) "StripOffsets" },
+    {  0x112, (char *) "Orientation" },
+    {  0x115, (char *) "SamplesPerPixel" },
+    {  0x116, (char *) "RowsPerStrip" },
+    {  0x117, (char *) "StripByteCounts" },
+    {  0x11a, (char *) "XResolution" },
+    {  0x11b, (char *) "YResolution" },
+    {  0x11c, (char *) "PlanarConfiguration" },
+    {  0x118, (char *) "MinSampleValue" },
+    {  0x119, (char *) "MaxSampleValue" },
+    {  0x11A, (char *) "XResolution" },
+    {  0x11B, (char *) "YResolution" },
+    {  0x11C, (char *) "PlanarConfiguration" },
+    {  0x11D, (char *) "PageName" },
+    {  0x11E, (char *) "XPosition" },
+    {  0x11F, (char *) "YPosition" },
+    {  0x120, (char *) "FreeOffsets" },
+    {  0x121, (char *) "FreeByteCounts" },
+    {  0x122, (char *) "GrayResponseUnit" },
+    {  0x123, (char *) "GrayResponseCurve" },
+    {  0x124, (char *) "T4Options" },
+    {  0x125, (char *) "T6Options" },
+    {  0x128, (char *) "ResolutionUnit" },
+    {  0x12d, (char *) "TransferFunction" },
+    {  0x131, (char *) "Software" },
+    {  0x132, (char *) "DateTime" },
+    {  0x13b, (char *) "Artist" },
+    {  0x13e, (char *) "WhitePoint" },
+    {  0x13f, (char *) "PrimaryChromaticities" },
+    {  0x140, (char *) "ColorMap" },
+    {  0x141, (char *) "HalfToneHints" },
+    {  0x142, (char *) "TileWidth" },
+    {  0x143, (char *) "TileLength" },
+    {  0x144, (char *) "TileOffsets" },
+    {  0x145, (char *) "TileByteCounts" },
+    {  0x14a, (char *) "SubIFD" },
+    {  0x14c, (char *) "InkSet" },
+    {  0x14d, (char *) "InkNames" },
+    {  0x14e, (char *) "NumberOfInks" },
+    {  0x150, (char *) "DotRange" },
+    {  0x151, (char *) "TargetPrinter" },
+    {  0x152, (char *) "ExtraSample" },
+    {  0x153, (char *) "SampleFormat" },
+    {  0x154, (char *) "SMinSampleValue" },
+    {  0x155, (char *) "SMaxSampleValue" },
+    {  0x156, (char *) "TransferRange" },
+    {  0x157, (char *) "ClipPath" },
+    {  0x158, (char *) "XClipPathUnits" },
+    {  0x159, (char *) "YClipPathUnits" },
+    {  0x15a, (char *) "Indexed" },
+    {  0x15b, (char *) "JPEGTables" },
+    {  0x15f, (char *) "OPIProxy" },
+    {  0x200, (char *) "JPEGProc" },
+    {  0x201, (char *) "JPEGInterchangeFormat" },
+    {  0x202, (char *) "JPEGInterchangeFormatLength" },
+    {  0x203, (char *) "JPEGRestartInterval" },
+    {  0x205, (char *) "JPEGLosslessPredictors" },
+    {  0x206, (char *) "JPEGPointTransforms" },
+    {  0x207, (char *) "JPEGQTables" },
+    {  0x208, (char *) "JPEGDCTables" },
+    {  0x209, (char *) "JPEGACTables" },
+    {  0x211, (char *) "YCbCrCoefficients" },
+    {  0x212, (char *) "YCbCrSubSampling" },
+    {  0x213, (char *) "YCbCrPositioning" },
+    {  0x214, (char *) "ReferenceBlackWhite" },
+    {  0x2bc, (char *) "ExtensibleMetadataPlatform" },
+    {  0x301, (char *) "Gamma" },
+    {  0x302, (char *) "ICCProfileDescriptor" },
+    {  0x303, (char *) "SRGBRenderingIntent" },
+    {  0x320, (char *) "ImageTitle" },
+    {  0x5001, (char *) "ResolutionXUnit" },
+    {  0x5002, (char *) "ResolutionYUnit" },
+    {  0x5003, (char *) "ResolutionXLengthUnit" },
+    {  0x5004, (char *) "ResolutionYLengthUnit" },
+    {  0x5005, (char *) "PrintFlags" },
+    {  0x5006, (char *) "PrintFlagsVersion" },
+    {  0x5007, (char *) "PrintFlagsCrop" },
+    {  0x5008, (char *) "PrintFlagsBleedWidth" },
+    {  0x5009, (char *) "PrintFlagsBleedWidthScale" },
+    {  0x500A, (char *) "HalftoneLPI" },
+    {  0x500B, (char *) "HalftoneLPIUnit" },
+    {  0x500C, (char *) "HalftoneDegree" },
+    {  0x500D, (char *) "HalftoneShape" },
+    {  0x500E, (char *) "HalftoneMisc" },
+    {  0x500F, (char *) "HalftoneScreen" },
+    {  0x5010, (char *) "JPEGQuality" },
+    {  0x5011, (char *) "GridSize" },
+    {  0x5012, (char *) "ThumbnailFormat" },
+    {  0x5013, (char *) "ThumbnailWidth" },
+    {  0x5014, (char *) "ThumbnailHeight" },
+    {  0x5015, (char *) "ThumbnailColorDepth" },
+    {  0x5016, (char *) "ThumbnailPlanes" },
+    {  0x5017, (char *) "ThumbnailRawBytes" },
+    {  0x5018, (char *) "ThumbnailSize" },
+    {  0x5019, (char *) "ThumbnailCompressedSize" },
+    {  0x501a, (char *) "ColorTransferFunction" },
+    {  0x501b, (char *) "ThumbnailData" },
+    {  0x5020, (char *) "ThumbnailImageWidth" },
+    {  0x5021, (char *) "ThumbnailImageHeight" },
+    {  0x5022, (char *) "ThumbnailBitsPerSample" },
+    {  0x5023, (char *) "ThumbnailCompression" },
+    {  0x5024, (char *) "ThumbnailPhotometricInterp" },
+    {  0x5025, (char *) "ThumbnailImageDescription" },
+    {  0x5026, (char *) "ThumbnailEquipMake" },
+    {  0x5027, (char *) "ThumbnailEquipModel" },
+    {  0x5028, (char *) "ThumbnailStripOffsets" },
+    {  0x5029, (char *) "ThumbnailOrientation" },
+    {  0x502a, (char *) "ThumbnailSamplesPerPixel" },
+    {  0x502b, (char *) "ThumbnailRowsPerStrip" },
+    {  0x502c, (char *) "ThumbnailStripBytesCount" },
+    {  0x502d, (char *) "ThumbnailResolutionX" },
+    {  0x502e, (char *) "ThumbnailResolutionY" },
+    {  0x502f, (char *) "ThumbnailPlanarConfig" },
+    {  0x5030, (char *) "ThumbnailResolutionUnit" },
+    {  0x5031, (char *) "ThumbnailTransferFunction" },
+    {  0x5032, (char *) "ThumbnailSoftwareUsed" },
+    {  0x5033, (char *) "ThumbnailDateTime" },
+    {  0x5034, (char *) "ThumbnailArtist" },
+    {  0x5035, (char *) "ThumbnailWhitePoint" },
+    {  0x5036, (char *) "ThumbnailPrimaryChromaticities" },
+    {  0x5037, (char *) "ThumbnailYCbCrCoefficients" },
+    {  0x5038, (char *) "ThumbnailYCbCrSubsampling" },
+    {  0x5039, (char *) "ThumbnailYCbCrPositioning" },
+    {  0x503A, (char *) "ThumbnailRefBlackWhite" },
+    {  0x503B, (char *) "ThumbnailCopyRight" },
+    {  0x5090, (char *) "LuminanceTable" },
+    {  0x5091, (char *) "ChrominanceTable" },
+    {  0x5100, (char *) "FrameDelay" },
+    {  0x5101, (char *) "LoopCount" },
+    {  0x5110, (char *) "PixelUnit" },
+    {  0x5111, (char *) "PixelPerUnitX" },
+    {  0x5112, (char *) "PixelPerUnitY" },
+    {  0x5113, (char *) "PaletteHistogram" },
+    {  0x1000, (char *) "RelatedImageFileFormat" },
+    {  0x1001, (char *) "RelatedImageLength" },
+    {  0x1002, (char *) "RelatedImageWidth" },
+    {  0x800d, (char *) "ImageID" },
+    {  0x80e3, (char *) "Matteing" },
+    {  0x80e4, (char *) "DataType" },
+    {  0x80e5, (char *) "ImageDepth" },
+    {  0x80e6, (char *) "TileDepth" },
+    {  0x828d, (char *) "CFARepeatPatternDim" },
+    {  0x828e, (char *) "CFAPattern" },
+    {  0x828f, (char *) "BatteryLevel" },
+    {  0x828d, (char *) "CFARepeatPatternDim" },
+    {  0x828e, (char *) "CFAPattern" },
+    {  0x828f, (char *) "BatteryLevel" },
+    {  0x8298, (char *) "Copyright" },
+    {  0x829a, (char *) "ExposureTime" },
+    {  0x829d, (char *) "FNumber" },
+    {  0x83bb, (char *) "IPTC/NAA" },
+    {  0x84e3, (char *) "IT8RasterPadding" },
+    {  0x84e5, (char *) "IT8ColorTable" },
+    {  0x8649, (char *) "ImageResourceInformation" },
+    {  0x8769, (char *) "ExifOffset" },
+    {  0x8773, (char *) "InterColorProfile" },
+    {  0x8822, (char *) "ExposureProgram" },
+    {  0x8824, (char *) "SpectralSensitivity" },
+    {  0x8825, (char *) "GPSInfo" },
+    {  0x8827, (char *) "ISOSpeedRatings" },
+    {  0x8828, (char *) "OECF" },
+    {  0x8829, (char *) "Interlace" },
+    {  0x882a, (char *) "TimeZoneOffset" },
+    {  0x882b, (char *) "SelfTimerMode" },
+    {  0x9000, (char *) "ExifVersion" },
+    {  0x9003, (char *) "DateTimeOriginal" },
+    {  0x9004, (char *) "DateTimeDigitized" },
+    {  0x9101, (char *) "ComponentsConfiguration" },
+    {  0x9102, (char *) "CompressedBitsPerPixel" },
+    {  0x9201, (char *) "ShutterSpeedValue" },
+    {  0x9202, (char *) "ApertureValue" },
+    {  0x9203, (char *) "BrightnessValue" },
+    {  0x9204, (char *) "ExposureBiasValue" },
+    {  0x9205, (char *) "MaxApertureValue" },
+    {  0x9206, (char *) "SubjectDistance" },
+    {  0x9207, (char *) "MeteringMode" },
+    {  0x9208, (char *) "LightSource" },
+    {  0x9209, (char *) "Flash" },
+    {  0x920a, (char *) "FocalLength" },
+    {  0x920b, (char *) "FlashEnergy" },
+    {  0x920c, (char *) "SpatialFrequencyResponse" },
+    {  0x920d, (char *) "Noise" },
+    {  0x9211, (char *) "ImageNumber" },
+    {  0x9212, (char *) "SecurityClassification" },
+    {  0x9213, (char *) "ImageHistory" },
+    {  0x9214, (char *) "SubjectArea" },
+    {  0x9215, (char *) "ExposureIndex" },
+    {  0x9216, (char *) "TIFF/EPStandardID" },
+    {  0x927c, (char *) "MakerNote" },
+    {  0x9C9b, (char *) "WinXP-Title" },
+    {  0x9C9c, (char *) "WinXP-Comments" },
+    {  0x9C9d, (char *) "WinXP-Author" },
+    {  0x9C9e, (char *) "WinXP-Keywords" },
+    {  0x9C9f, (char *) "WinXP-Subject" },
+    {  0x9286, (char *) "UserComment" },
+    {  0x9290, (char *) "SubSecTime" },
+    {  0x9291, (char *) "SubSecTimeOriginal" },
+    {  0x9292, (char *) "SubSecTimeDigitized" },
+    {  0xa000, (char *) "FlashPixVersion" },
+    {  0xa001, (char *) "ColorSpace" },
+    {  0xa002, (char *) "ExifImageWidth" },
+    {  0xa003, (char *) "ExifImageLength" },
+    {  0xa004, (char *) "RelatedSoundFile" },
+    {  0xa005, (char *) "InteroperabilityOffset" },
+    {  0xa20b, (char *) "FlashEnergy" },
+    {  0xa20c, (char *) "SpatialFrequencyResponse" },
+    {  0xa20d, (char *) "Noise" },
+    {  0xa20e, (char *) "FocalPlaneXResolution" },
+    {  0xa20f, (char *) "FocalPlaneYResolution" },
+    {  0xa210, (char *) "FocalPlaneResolutionUnit" },
+    {  0xa214, (char *) "SubjectLocation" },
+    {  0xa215, (char *) "ExposureIndex" },
+    {  0xa216, (char *) "TIFF/EPStandardID" },
+    {  0xa217, (char *) "SensingMethod" },
+    {  0xa300, (char *) "FileSource" },
+    {  0xa301, (char *) "SceneType" },
+    {  0xa302, (char *) "CFAPattern" },
+    {  0xa401, (char *) "CustomRendered" },
+    {  0xa402, (char *) "ExposureMode" },
+    {  0xa403, (char *) "WhiteBalance" },
+    {  0xa404, (char *) "DigitalZoomRatio" },
+    {  0xa405, (char *) "FocalLengthIn35mmFilm" },
+    {  0xa406, (char *) "SceneCaptureType" },
+    {  0xa407, (char *) "GainControl" },
+    {  0xa408, (char *) "Contrast" },
+    {  0xa409, (char *) "Saturation" },
+    {  0xa40a, (char *) "Sharpness" },
+    {  0xa40b, (char *) "DeviceSettingDescription" },
+    {  0xa40c, (char *) "SubjectDistanceRange" },
+    {  0xa420, (char *) "ImageUniqueID" },
+    {  0xc4a5, (char *) "PrintImageMatching" },
     {  0x0000, (char *) NULL}
   };
 
@@ -864,7 +992,7 @@ static int GenerateEXIFAttribute(Image *image,const char *specification)
       Determine how many entries there are in the current IFD.
     */
     nde=ReadUint16(msb_order,ifdp);
-    for (; de < nde; de++)
+    for ( ; de < nde; de++)
     {
       long
         n,
@@ -896,7 +1024,7 @@ static int GenerateEXIFAttribute(Image *image,const char *specification)
           oval=ReadUint32(msb_order,pde+8);
           if ((size_t) (oval+n) > length)
             continue;
-          pval=(char *)(tiffp+oval);
+          pval=(char *) (tiffp+oval);
         }
       if ((all != 0)  || (tag == (unsigned long) t))
         {
@@ -912,13 +1040,6 @@ static int GenerateEXIFAttribute(Image *image,const char *specification)
               value=AcquireString(buffer);
               break;
             }
-            case EXIF_FMT_BYTE:
-            {
-              (void) FormatMagickString(buffer,MaxTextExtent,"%ld",
-                (long) (*(unsigned char *) pval));
-              value=AcquireString(buffer);
-              break;
-            }
             case EXIF_FMT_SSHORT:
             {
               (void) FormatMagickString(buffer,MaxTextExtent,"%hd",
@@ -979,6 +1100,7 @@ static int GenerateEXIFAttribute(Image *image,const char *specification)
             }
             default:
             case EXIF_FMT_UNDEFINED:
+            case EXIF_FMT_BYTE:
             case EXIF_FMT_STRING:
             {
               value=(char *) AcquireMagickMemory((size_t) n+1);
@@ -1083,7 +1205,7 @@ MagickExport const ImageAttribute *GetImageAttribute(const Image *image,
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if (image->attributes == (void *) NULL)
    return((const ImageAttribute *) NULL);
   if (key == (const char *) NULL)
@@ -1317,8 +1439,8 @@ MagickExport const ImageAttribute *GetImageInfoAttribute(
             page;
 
           p=image;
-          for (page=1; p->previous != (Image *) NULL; page++)
-            p=p->previous;
+          for (page=1; GetPreviousImageInList(p) != (Image *) NULL; page++)
+            p=GetPreviousImageInList(p);
           (void) FormatMagickString(attribute,MaxTextExtent,"%lu",page);
           break;
         }
@@ -1407,7 +1529,7 @@ MagickExport const ImageAttribute *GetNextImageAttribute(const Image *image)
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if (image->attributes == (void *) NULL)
     return((const ImageAttribute *) NULL);
   return((const ImageAttribute *) GetNextValueInSplayTree(image->attributes));
@@ -1442,7 +1564,7 @@ MagickExport void ResetImageAttributeIterator(const Image *image)
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if (image->attributes == (void *) NULL)
     return;
   ResetSplayTreeIterator(image->attributes);
@@ -1504,7 +1626,7 @@ MagickExport  MagickBooleanType SetImageAttribute(Image *image,const char *key,
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if ((key == (const char *) NULL) || (*key == '\0'))
     return(MagickFalse);
   if (image->attributes == (void *) NULL)
