@@ -333,7 +333,7 @@ MagickExport const CoderInfo **GetCoderInfoList(const char *pattern,
     Allocate coder list.
   */
   assert(pattern != (char *) NULL);
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),pattern);
+  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",pattern);
   assert(number_coders != (unsigned long *) NULL);
   *number_coders=0;
   p=GetCoderInfo("*",exception);
@@ -418,7 +418,7 @@ MagickExport char **GetCoderList(const char *pattern,
     Allocate coder list.
   */
   assert(pattern != (char *) NULL);
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),pattern);
+  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",pattern);
   assert(number_coders != (unsigned long *) NULL);
   *number_coders=0;
   p=GetCoderInfo("*",exception);
