@@ -66,7 +66,7 @@
 %  RGBTransformImage() converts the reference image from RGB to an alternate
 %  colorspace.  The transformation matrices are not the standard ones: the
 %  weights are rescaled to normalized the range of the transformed values to
-%  be [0..MaxRGB].
+%  be [0..QuantumRange].
 %
 %  The format of the RGBTransformImage method is:
 %
@@ -114,7 +114,7 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   assert(colorspace != RGBColorspace);
   assert(colorspace != TransparentColorspace);
   assert(colorspace != UndefinedColorspace);
@@ -159,9 +159,9 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
         indexes=GetIndexes(image);
         for (x=0; x < (long) image->columns; x++)
         {
-          cyan=(Quantum) (MaxRGB-q->red);
-          magenta=(Quantum) (MaxRGB-q->green);
-          yellow=(Quantum) (MaxRGB-q->blue);
+          cyan=(Quantum) (QuantumRange-q->red);
+          magenta=(Quantum) (QuantumRange-q->green);
+          yellow=(Quantum) (QuantumRange-q->blue);
           black=(Quantum)
             (cyan < magenta ? Min(cyan,yellow) : Min(magenta,yellow));
           q->red=cyan;
@@ -234,9 +234,9 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
         for (x=(long) image->columns-1; x >= 0; x--)
         {
           TransformHSB(q->red,q->green,q->blue,&hue,&saturation,&brightness);
-          q->red=RoundToQuantum(MaxRGB*hue);
-          q->green=RoundToQuantum(MaxRGB*saturation);
-          q->blue=RoundToQuantum(MaxRGB*brightness);
+          q->red=RoundToQuantum(QuantumRange*hue);
+          q->green=RoundToQuantum(QuantumRange*saturation);
+          q->blue=RoundToQuantum(QuantumRange*brightness);
           q++;
         }
         if (SyncImagePixels(image) == MagickFalse)
@@ -271,9 +271,9 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
         for (x=(long) image->columns-1; x >= 0; x--)
         {
           TransformHSL(q->red,q->green,q->blue,&hue,&saturation,&luminosity);
-          q->red=RoundToQuantum(MaxRGB*hue);
-          q->green=RoundToQuantum(MaxRGB*saturation);
-          q->blue=RoundToQuantum(MaxRGB*luminosity);
+          q->red=RoundToQuantum(QuantumRange*hue);
+          q->green=RoundToQuantum(QuantumRange*saturation);
+          q->blue=RoundToQuantum(QuantumRange*luminosity);
           q++;
         }
         if (SyncImagePixels(image) == MagickFalse)
@@ -308,9 +308,9 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
         for (x=(long) image->columns-1; x >= 0; x--)
         {
           TransformHWB(q->red,q->green,q->blue,&hue,&whiteness,&blackness);
-          q->red=RoundToQuantum(MaxRGB*hue);
-          q->green=RoundToQuantum(MaxRGB*whiteness);
-          q->blue=RoundToQuantum(MaxRGB*blackness);
+          q->red=RoundToQuantum(QuantumRange*hue);
+          q->green=RoundToQuantum(QuantumRange*whiteness);
+          q->blue=RoundToQuantum(QuantumRange*blackness);
           q++;
         }
         if (SyncImagePixels(image) == MagickFalse)
@@ -388,7 +388,7 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           I3 =-0.25000*R+0.50000*G-0.25000*B
 
         I and Q, normally -0.5 through 0.5, are normalized to the range 0
-        through MaxRGB.
+        through QuantumRange.
       */
       primary_info.y=(MaxMap+1)/2.0;
       primary_info.z=(MaxMap+1)/2.0;
@@ -478,7 +478,7 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           Cr=  0.500000*R-0.418688*G-0.081316*B
 
         Cb and Cr, normally -0.5 through 0.5, are normalized to the range 0
-        through MaxRGB.
+        through QuantumRange.
       */
       primary_info.y=(MaxMap+1)/2.0;
       primary_info.z=(MaxMap+1)/2.0;
@@ -545,7 +545,7 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           Q = 0.21100*R-0.52300*G+0.31200*B
 
         I and Q, normally -0.5 through 0.5, are normalized to the range 0
-        through MaxRGB.
+        through QuantumRange.
       */
       primary_info.y=(MaxMap+1)/2.0;
       primary_info.z=(MaxMap+1)/2.0;
@@ -573,7 +573,7 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           Pr=  0.500000*R-0.418688*G-0.081312*B
 
         Pb and Pr, normally -0.5 through 0.5, are normalized to the range 0
-        through MaxRGB.
+        through QuantumRange.
       */
       primary_info.y=(MaxMap+1)/2.0;
       primary_info.z=(MaxMap+1)/2.0;
@@ -602,7 +602,7 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           V =  0.61500*R-0.51500*G-0.10000*B
 
         U and V, normally -0.5 through 0.5, are normalized to the range 0
-        through MaxRGB.  Note that U = 0.493*(B-Y), V = 0.877*(R-Y).
+        through QuantumRange.  Note that U = 0.493*(B-Y), V = 0.877*(R-Y).
       */
       primary_info.y=(MaxMap+1)/2.0;
       primary_info.z=(MaxMap+1)/2.0;
@@ -738,7 +738,7 @@ MagickExport MagickBooleanType SetImageColorspace(Image *image,
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   assert(image->colorspace != UndefinedColorspace);
   assert(colorspace != UndefinedColorspace);
   if (image->colorspace == colorspace)
@@ -769,7 +769,7 @@ MagickExport MagickBooleanType SetImageColorspace(Image *image,
 %  TransformRGBImage() converts the reference image from an alternate
 %  colorspace to RGB.  The transformation matrices are not the standard ones:
 %  the weights are rescaled to normalize the range of the transformed values to
-%  be [0..MaxRGB].
+%  be [0..QuantumRange].
 %
 %  The format of the TransformRGBImage method is:
 %
@@ -879,7 +879,7 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   assert(image->colorspace != UndefinedColorspace);
   switch (colorspace)
   {
@@ -915,12 +915,12 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
         indexes=GetIndexes(image);
         for (x=0; x < (long) image->columns; x++)
         {
-          q->red=RoundToQuantum(QuantumScale*
-            ((MagickRealType) (MaxRGB-q->red)*(MaxRGB-indexes[x])));
-          q->green=RoundToQuantum(QuantumScale*
-            ((MagickRealType) (MaxRGB-q->green)*(MaxRGB-indexes[x])));
-          q->blue=RoundToQuantum(QuantumScale*
-            ((MagickRealType) (MaxRGB-q->blue)*(MaxRGB-indexes[x])));
+          q->red=RoundToQuantum(QuantumScale* ((MagickRealType)
+            (QuantumRange-q->red)*(QuantumRange-indexes[x])));
+          q->green=RoundToQuantum(QuantumScale* ((MagickRealType)
+            (QuantumRange-q->green)*(QuantumRange-indexes[x])));
+          q->blue=RoundToQuantum(QuantumScale* ((MagickRealType)
+            (QuantumRange-q->blue)*(QuantumRange-indexes[x])));
           q++;
         }
         if (SyncImagePixels(image) == MagickFalse)
@@ -1056,7 +1056,7 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           B = I1-1.00000*I2-0.66668*I3
 
         I and Q, normally -0.5 through 0.5, must be normalized to the range 0
-        through MaxRGB.
+        through QuantumRange.
       */
       for (i=0; i <= (long) MaxMap; i++)
       {
@@ -1134,7 +1134,7 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           B = Y+1.772000*Cb
 
         Cb and Cr, normally -0.5 through 0.5, must be normalized to the range 0
-        through MaxRGB.
+        through QuantumRange.
       */
       for (i=0; i <= (long) MaxMap; i++)
       {
@@ -1189,7 +1189,7 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           B = Y-1.10370*I+1.70060*Q
 
         I and Q, normally -0.5 through 0.5, must be normalized to the range 0
-        through MaxRGB.
+        through QuantumRange.
       */
       for (i=0; i <= (long) MaxMap; i++)
       {
@@ -1215,7 +1215,7 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           B = Y+1.772000*C1
 
         Pb and Pr, normally -0.5 through 0.5, must be normalized to the range 0
-        through MaxRGB.
+        through QuantumRange.
       */
       for (i=0; i <= (long) MaxMap; i++)
       {
@@ -1242,7 +1242,7 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           B = Y+2.02790*U
 
         U and V, normally -0.5 through 0.5, must be normalized to the range 0
-        through MaxRGB.
+        through QuantumRange.
       */
       for (i=0; i <= (long) MaxMap; i++)
       {
