@@ -149,13 +149,13 @@ MagickExport Image *CompareImageChannels(Image *image,
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   assert(reconstruct_image != (const Image *) NULL);
   assert(reconstruct_image->signature == MagickSignature);
   assert(distortion != (double *) NULL);
   *distortion=0.0;
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if ((reconstruct_image->columns != image->columns) ||
       (reconstruct_image->rows != image->rows))
     ThrowImageException(ImageError,"ImageSizeDiffers");
@@ -213,10 +213,10 @@ MagickExport Image *CompareImageChannels(Image *image,
           difference=MagickTrue;
       SetMagickPixelPacket(q,reconstruct_indexes+x,&source);
       if (difference != MagickFalse)
-        MagickPixelCompositeOver(&source,9.0*MaxRGB/10.0,&red,
+        MagickPixelCompositeOver(&source,9.0*QuantumRange/10.0,&red,
           (MagickRealType) red.opacity,&composite);
       else
-        MagickPixelCompositeOver(&source,9.0*MaxRGB/10.0,&white,
+        MagickPixelCompositeOver(&source,9.0*QuantumRange/10.0,&white,
           (MagickRealType) white.opacity,&composite);
       SetPixelPacket(&composite,r,difference_indexes+x);
       p++;
@@ -301,7 +301,7 @@ static void CompareUsage(void)
       "-verbose             print detailed information about the image",
       "-version             print version information",
       "-virtual-pixel method",
-      "                     access method for pixels outside the boundaries of the image",
+      "                     virtual pixel access method",
       (char *) NULL
     };
 
@@ -383,7 +383,7 @@ MagickExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
   if (argc < 2)
     CompareUsage();
   channel=AllChannels;
-  difference_image=(Image *) NULL;
+  difference_image=NewImageList();
   distortion=0.0;
   j=1;
   k=0;
@@ -391,7 +391,7 @@ MagickExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
   metric=UndefinedMetric;
   option=(char *) NULL;
   pend=MagickFalse;
-  reconstruct_image=(Image *) NULL;
+  reconstruct_image=NewImageList();
   status=MagickTrue;
   /*
     Compare an image.
@@ -438,7 +438,11 @@ MagickExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
         status&=(image != (Image *) NULL) &&
           (exception->severity < ErrorException);
         if (image == (Image *) NULL)
-          continue;
+          {
+            if (image_stack[k] != (Image *) NULL)
+              InheritException(&image_stack[k]->exception,exception);
+            continue;
+          }
         GetImageException(image,exception);
         AppendImageToList(&image_stack[k],image);
         continue;
@@ -1100,7 +1104,7 @@ static MagickRealType GetPeakSignalToNoiseRatio(const Image *image,
     distortion;
 
   distortion=GetMeanSquaredError(image,reconstruct_image,channel,exception);
-  return(20.0*log10(MaxRGB/sqrt((double) distortion)));
+  return(20.0*log10(QuantumRange/sqrt((double) distortion)));
 }
 
 static MagickRealType GetRootMeanSquaredError(const Image *image,
@@ -1121,13 +1125,13 @@ MagickExport MagickBooleanType GetImageChannelDistortion(Image *image,
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   assert(reconstruct_image != (const Image *) NULL);
   assert(reconstruct_image->signature == MagickSignature);
   assert(distortion != (double *) NULL);
   *distortion=0.0;
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if ((reconstruct_image->columns != image->columns) ||
       (reconstruct_image->rows != image->rows))
     ThrowBinaryException(ImageError,"ImageSizeDiffers",image->filename);
@@ -1316,8 +1320,9 @@ MagickExport MagickBooleanType IsImagesEqual(Image *image,
     }
   }
   image->error.mean_error_per_pixel=(double) (mean_error_per_pixel/area);
-  image->error.normalized_mean_error=(double) (mean_error/area/MaxRGB/MaxRGB);
-  image->error.normalized_maximum_error=(double) (maximum_error/MaxRGB);
+  image->error.normalized_mean_error=(double)
+    (mean_error/area/QuantumRange/QuantumRange);
+  image->error.normalized_maximum_error=(double) (maximum_error/QuantumRange);
   status=(MagickBooleanType)
     (image->error.mean_error_per_pixel == 0.0 ? MagickTrue : MagickFalse);
   return(status);
