@@ -31,39 +31,14 @@ extern "C" {
 #define RoundToUnity(value) \
   ((value) < 0.0 ? 0.0 : ((value) > 1.0) ? 1.0 : (value))
 
-static inline MagickRealType MagickAtop_(const MagickRealType p,
+static inline MagickRealType MagickOver_(const MagickRealType p,
   const MagickRealType alpha,const MagickRealType q,const MagickRealType beta)
 {
   MagickRealType
     pixel;
-                                                                                
-  pixel=((1-QuantumScale*alpha)*p*(1-QuantumScale*beta)+(1-QuantumScale*beta)*
-    q*QuantumScale*alpha);
-  return(pixel);
-}
-                                                                                
-static inline void MagickCompositeAtop(const PixelPacket *p,
-  const MagickRealType alpha,const PixelPacket *q,const MagickRealType beta,
-  PixelPacket *composite)
-{
-  MagickRealType
-    gamma;
-                                                                                
-  gamma=(1-QuantumScale*beta);
-  composite->opacity=(Quantum) (MaxRGB*(1.0-gamma)+0.5);
-  gamma=1.0/(gamma <= MagickEpsilon ? 1.0 : gamma);
-  composite->red=(Quantum) (gamma*MagickAtop_((MagickRealType) p->red,alpha,
-    (MagickRealType) q->red,beta)+0.5);
-  composite->green=(Quantum) (gamma*MagickAtop_((MagickRealType) p->green,alpha,
-    (MagickRealType) q->green,beta)+0.5);
-  composite->blue=(Quantum) (gamma*MagickAtop_((MagickRealType) p->blue,alpha,
-    (MagickRealType) q->blue,beta)+0.5);
-}
 
-static inline MagickRealType MagickOver_(const MagickRealType p,
-  const MagickRealType alpha,const MagickRealType q,const MagickRealType beta)
-{
-  return((1-QuantumScale*alpha)*p+(1-QuantumScale*beta)*q*QuantumScale*alpha);
+  pixel=(1.0-QuantumScale*alpha)*p+(1.0-QuantumScale*beta)*q*QuantumScale*alpha;
+  return(pixel);
 }
                                                                                 
 static inline void MagickCompositeOver(const PixelPacket *p,
@@ -74,7 +49,7 @@ static inline void MagickCompositeOver(const PixelPacket *p,
     gamma;
                                                                                 
   gamma=1.0-QuantumScale*QuantumScale*alpha*beta;
-  composite->opacity=(Quantum) (MaxRGB*(1.0-gamma)+0.5);
+  composite->opacity=(Quantum) (QuantumRange*(1.0-gamma)+0.5);
   gamma=1.0/(gamma <= MagickEpsilon ? 1.0 : gamma);
   composite->red=(Quantum) (gamma*MagickOver_((MagickRealType) p->red,alpha,
     (MagickRealType) q->red,beta)+0.5);
@@ -92,7 +67,7 @@ static inline void MagickPixelCompositeOver(const MagickPixelPacket *p,
     gamma;
 
   gamma=1.0-QuantumScale*QuantumScale*alpha*beta;
-  composite->opacity=MaxRGB*(1.0-gamma);
+  composite->opacity=QuantumRange*(1.0-gamma);
   gamma=1.0/(gamma <= MagickEpsilon ? 1.0 : gamma);
   composite->red=gamma*MagickOver_(p->red,alpha,q->red,beta);
   composite->green=gamma*MagickOver_(p->green,alpha,q->green,beta);
