@@ -301,7 +301,7 @@ MagickExport const ConfigureInfo **GetConfigureInfoList(const char *pattern,
     Allocate configure list.
   */
   assert(pattern != (char *) NULL);
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),pattern);
+  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",pattern);
   assert(number_options != (unsigned long *) NULL);
   *number_options=0;
   p=GetConfigureInfo("*",exception);
@@ -396,7 +396,7 @@ MagickExport char **GetConfigureList(const char *pattern,
     Allocate configure list.
   */
   assert(pattern != (char *) NULL);
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),pattern);
+  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",pattern);
   assert(number_options != (unsigned long *) NULL);
   *number_options=0;
   p=GetConfigureInfo("*",exception);
@@ -469,7 +469,7 @@ MagickExport LinkedListInfo *GetConfigureOptions(const char *filename,
     *xml;
 
   assert(filename != (const char *) NULL);
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),filename);
+  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",filename);
   assert(exception != (ExceptionInfo *) NULL);
   (void) CopyMagickString(path,filename,MaxTextExtent);
   /*
@@ -551,7 +551,7 @@ MagickExport LinkedListInfo *GetConfigurePaths(const char *filename,
     *paths;
 
   assert(filename != (const char *) NULL);
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),filename);
+  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",filename);
   assert(exception != (ExceptionInfo *) NULL);
   (void) CopyMagickString(path,filename,MaxTextExtent);
   paths=NewLinkedList(0);
@@ -591,6 +591,9 @@ MagickExport LinkedListInfo *GetConfigurePaths(const char *filename,
 #if defined(MagickShareConfigPath)
   (void) AppendValueToLinkedList(paths,AcquireString(MagickShareConfigPath));
 #endif
+#if defined(MagickDocumentPath)
+  (void) AppendValueToLinkedList(paths,AcquireString(MagickDocumentPath));
+#endif
 #if defined(MagickSharePath)
   (void) AppendValueToLinkedList(paths,AcquireString(MagickSharePath));
 #endif
