@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -142,6 +142,7 @@ static void ConjureUsage(void)
       "-help                print program options",
       "-log format          format of debugging information",
       "-monitor             monitor progress",
+      "-quiet               suppress all error or warning messages",
       "-verbose             print detailed information about the image",
       "-version             print version information",
       (char *) NULL
@@ -259,6 +260,8 @@ MagickExport MagickBooleanType ConjureImageCommand(ImageInfo *image_info,
           }
         if (LocaleCompare("monitor",option+1) == 0)
           continue;
+        if (LocaleCompare("quiet",option+1) == 0)
+          continue;
         if (LocaleCompare("verbose",option+1) == 0)
           {
             image_info->verbose=(*option == '-') ? MagickTrue : MagickFalse;
@@ -275,7 +278,7 @@ MagickExport MagickBooleanType ConjureImageCommand(ImageInfo *image_info,
         /*
           Persist key/value pair.
         */
-        (void) SetImageAttribute(image_info->attributes,option+1,(char *) NULL);
+        (void) DeleteImageAttribute(image_info->attributes,option+1);
         status&=SetImageAttribute(image_info->attributes,option+1,argv[i+1]);
         if (status == MagickFalse)
           ThrowConjureException(ImageError,"UnableToPersistKey",option);
@@ -285,7 +288,7 @@ MagickExport MagickBooleanType ConjureImageCommand(ImageInfo *image_info,
     /*
       Interpret MSL script.
     */
-    (void) SetImageAttribute(image_info->attributes,"filename",(char *) NULL);
+    (void) DeleteImageAttribute(image_info->attributes,"filename");
     status&=SetImageAttribute(image_info->attributes,"filename",argv[i]);
     if (status == MagickFalse)
       ThrowConjureException(ImageError,"UnableToPersistKey",argv[i]);
