@@ -87,7 +87,7 @@ static Image
 %  ConstituteImage() returns an image from the the pixel data you supply.
 %  The pixel data must be in scanline order top-to-bottom.  The data can be
 %  char, short int, int, float, or double.  Float and double require the
-%  pixels to be normalized [0..1], otherwise [0..MaxRGB].  For example, to
+%  pixels to be normalized [0..1], otherwise [0..QuantumRange].  For example, to
 %  create a 640x480 image from unsigned red-green-blue character data, use:
 %
 %      image = ConstituteImage(640,480,"RGB",CharPixel,pixels,&exception);
@@ -111,8 +111,8 @@ static Image
 %      P = pad.
 %
 %    o storage: Define the data type of the pixels.  Float and double types are
-%      expected to be normalized [0..1] otherwise [0..MaxRGB].  Choose from
-%      these types: CharPixel, DoublePixel, FloatPixel, IntegerPixel,
+%      expected to be normalized [0..1] otherwise [0..QuantumRange].  Choose
+%      from these types: CharPixel, DoublePixel, FloatPixel, IntegerPixel,
 %      LongPixel, QuantumPixel, or ShortPixel.
 %
 %    o pixels: This array of values contain the pixel components as defined by
@@ -137,7 +137,7 @@ MagickExport Image *ConstituteImage(const unsigned long columns,
     Allocate image structure.
   */
   assert(map != (const char *) NULL);
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),map);
+  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",map);
   assert(pixels != (void *) NULL);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
@@ -240,16 +240,20 @@ MagickExport Image *PingImage(const ImageInfo *image_info,
   assert(image_info != (ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   (void) SetExceptionInfo(exception,UndefinedException);
   ping_info=CloneImageInfo(image_info);
   ping_info->ping=MagickTrue;
   image=ReadStream(ping_info,&PingStream,exception);
   ping_info=DestroyImageInfo(ping_info);
-  ResetTimer(&image->timer);
-  if ((image != (Image *) NULL) && (image_info->verbose != MagickFalse))
-    (void) IdentifyImage(image,stdout,MagickFalse);
+  if (image != (Image *) NULL)
+    {
+      ResetTimer(&image->timer);
+	    if (image_info->verbose != MagickFalse)
+        (void) IdentifyImage(image,stdout,MagickFalse);
+    }
   return(image);
 }
 
@@ -322,7 +326,8 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
   assert(image_info->signature == MagickSignature);
   assert(image_info->filename != (char *) NULL);
   if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   (void) SetExceptionInfo(exception,UndefinedException);
   if (*image_info->filename == '@')
@@ -372,7 +377,7 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
       CloseBlob(image);
       image=DestroyImage(image);
     }
-  image=(Image *) NULL;
+  image=NewImageList();
   if ((magick_info != (const MagickInfo *) NULL) &&
       (GetMagickDecoder(magick_info) != (DecoderHandler *) NULL))
     {
@@ -457,7 +462,7 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
       "notify the developers",image->magick,exception->severity);
   if (IsBlobTemporary(image) != MagickFalse)
     (void) RelinquishUniqueFileResource(read_info->filename);
-  if ((image->next != (Image *) NULL) &&
+  if ((GetNextImageInList(image) != (Image *) NULL) &&
       (IsSceneGeometry(read_info->scenes,MagickFalse) != MagickFalse))
     {
       Image
@@ -482,7 +487,7 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
       read_info=DestroyImageInfo(read_info);
       return((Image *) NULL);
     }
-  for (next=image; next; next=next->next)
+  for (next=image; next != (Image *) NULL; next=GetNextImageInList(next))
   {
     next->taint=MagickFalse;
     (void) CopyMagickString(next->magick,magick,MaxTextExtent);
@@ -642,7 +647,8 @@ static Image *ReadImages(const ImageInfo *image_info,ExceptionInfo *exception)
   assert(image_info != (ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   command=(char *) FileToBlob(image_info->filename+1,&length,exception);
   if (command == (char *) NULL)
@@ -653,28 +659,15 @@ static Image *ReadImages(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Read the images into a linked list.
   */
-  image=(Image *) NULL;
   read_info=CloneImageInfo(image_info);
+  image=NewImageList();
   for (i=1; i < number_images; i++)
   {
     (void) CopyMagickString(read_info->filename,images[i],MaxTextExtent);
     next=ReadImage(read_info,exception);
     if (next == (Image *) NULL)
       continue;
-    if (image == (Image *) NULL)
-      image=next;
-    else
-      {
-        register Image
-          *q;
-
-        /*
-          Link image into image list.
-        */
-        for (q=image; q->next != (Image *) NULL; q=q->next);
-        next->previous=q;
-        q->next=next;
-      }
+    AppendImageToList(&image,next);
   }
   read_info=DestroyImageInfo(read_info);
   for (i=1; i < number_images; i++)
@@ -733,7 +726,7 @@ MagickExport Image *ReadInlineImage(const ImageInfo *image_info,
     *p;
 
   (void) SetExceptionInfo(exception,UndefinedException);
-  image=(Image *) NULL;
+  image=NewImageList();
   for (p=content; (*p != ',') && (*p != '\0'); p++);
   if (*p == '\0')
     ThrowReaderException(CorruptImageWarning,"CorruptImage");
@@ -836,7 +829,8 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
   assert(image_info != (ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   (void) SetExceptionInfo(&image->exception,UndefinedException);
@@ -859,7 +853,8 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
     }
   (void) CopyMagickString(filename,image->filename,MaxTextExtent);
   SyncImageInfo(write_info,image,&sans_exception);
-  if ((image->next == (Image *) NULL) && (image->previous == (Image *) NULL) &&
+  if ((GetNextImageInList(image) == (Image *) NULL) &&
+      (GetPreviousImageInList(image) == (Image *) NULL) &&
       (write_info->page == (char *) NULL) &&
       (IsTaintImage(image) == MagickFalse))
     {
@@ -1036,20 +1031,21 @@ MagickExport MagickBooleanType WriteImages(const ImageInfo *image_info,
   assert(images != (Image *) NULL);
   assert(images->signature == MagickSignature);
   if (images->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),images->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",images->filename);
   assert(exception != (ExceptionInfo *) NULL);
   write_info=CloneImageInfo(image_info);
   images=GetFirstImageInList(images);
   if (filename != (const char *) NULL)
-    for (p=images; p != (Image *) NULL; p=p->next)
+    for (p=images; p != (Image *) NULL; p=GetNextImageInList(p))
       (void) CopyMagickString(p->filename,filename,MaxTextExtent);
   (void) CopyMagickString(write_info->filename,images->filename,MaxTextExtent);
   if (*write_info->magick == '\0')
     (void) CopyMagickString(write_info->magick,images->magick,MaxTextExtent);
   (void) SetImageInfo(write_info,MagickTrue,exception);
   (void) SetExceptionInfo(exception,UndefinedException);
-  for (p=images; p->next != (Image *) NULL; p=p->next)
-    if (p->scene >= p->next->scene)
+  p=images;
+  for ( ; GetNextImageInList(p) != (Image *) NULL; p=GetNextImageInList(p))
+    if (p->scene >= GetNextImageInList(p)->scene)
       {
         register long
           i;
@@ -1058,12 +1054,12 @@ MagickExport MagickBooleanType WriteImages(const ImageInfo *image_info,
           Generate consistent scene numbers.
         */
         i=0;
-        for (p=images; p != (Image *) NULL; p=p->next)
+        for (p=images; p != (Image *) NULL; p=GetNextImageInList(p))
           p->scene=(unsigned long) i++;
         break;
       }
   status=MagickTrue;
-  for (p=images; p != (Image *) NULL; p=p->next)
+  for (p=images; p != (Image *) NULL; p=GetNextImageInList(p))
   {
     status&=WriteImage(write_info,p);
     if (p->exception.severity >= ErrorException)
